package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````]!4``#0````<L0```````#0`(``,
M`"@`&0`8``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````T`\`
M`-`/```$`````!````$`````$````!`````0``#/,P``SS,```4`````$```
M`0````!0````4````%```$!.``!`3@``!``````0```!````X*T``."M``#@
MK0``-`(``&`"```&`````!````(```#HK0``Z*T``.BM``#P````\`````8`
M```$````!````,P!``#,`0``S`$``$P```!,````!`````0```!3Y71D\`$`
M`/`!``#P`0``*````"@````$````!````%#E=&1PD```<)```'"0```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DX*T``."M``#@K0``(`(``"`"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````4`````P```$=.50`.JL8S&Y+[[XLWM@E-#`AYF]41
MW`0````8````!0```$=.50`!``'`!`````D````"``'`!`````$````1````
M2`````@````(`````!`0`"5`!(`H`!`$H(8`A("!``(+(`0).(`208H$"`@`
M````2````$P```!0````40```%@```!9````6@````````!<````70``````
M``!>````7P```&$``````````````.K3[PYNQ=\?:G^:?,_>1RT@_^0.+L6;
MMM1DU'RYC?$.V7%8'/JA;&#"Y3\L0OK7AYA/PYNR`8MONN.2?.-'Q@%5PSS2
M9Z_,9D)%U>R)!W#3,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)````````````
M`````````)@"`````````````!$``````@`````````````2````;P$`````
M````````$@```+$!`````````````!(```!3```````````````2````;P(`
M````````````$@```.T"`````````````"$```"-`@`````````````2````
M$```````````````$@```$L``````````````!(```!;```````````````2
M````*```````````````$@```)P``````````````"`````8`0``````````
M```2````/0(`````````````$@```&$!`````````````!(```!Z`@``````
M```````2````E0``````````````$@```!@``````````````!(```"B`0``
M```````````2````K@(`````````````$@```"X``````````````!(```"1
M`0`````````````2````4P$`````````````$@```#P``````````````!(`
M``!:`0`````````````2````C0``````````````$@````$`````````````
M`!(```#Q```````````````2````+0(`````````````$@```.\"````````
M`````"$```"Z```````````````2````\`(`````````````$0```/L!````
M`````````!(```"]`0`````````````2````)@$`````````````$@```#T!
M`````````````!(````?```````````````2````0P``````````````$@``
M`#<!`````````````!(````2`0`````````````2````!@0`````````````
M$@```/8``````````````"````"%```````````````2````[@(`````````
M````$0```$8"`````````````!(```"G`@`````````````2````PP``````
M````````(@```(```````````````!(```!?`@`````````````2````Y0$`
M````````````$@```/@"`````````````!(```!1`@`````````````2````
MA@(`````````````$@```+T"`````````````!(````)```````````````1
M````C```````````````$@```-@!`````````````!$````,`@``````````
M```2````9```````````````(````#4``````````````!(```#;`@``````
M```````2````M@(`````````````$@```,0"`````````````!(```#V`0``
M```````````2````UP``````````````(````-(``````````````!(```!^
M`0`````````````6````TP(`````````````$@```$P!`````````````!(`
M```?`@`````````````2````T@$``,A#```!````$@`-`+@#``"`,@``Q0``
M`!(`#`#H`@``P!,``#0"```2``P`%`0``&`I``#P!@``$@`,`$\#``"@'@``
M-0(``!(`#`#$`P``D!X```4````2``P`(00``%`P```E`@``$@`,`)0#````
M$````0```!(`"0!Z`P``%+`````````0`!8`/0,``'`H``#P````$@`,`&8#
M```P'0``-@```!(`#`"&`P``H#\```8"```2``P`F@,``(`F```T````$@`,
M`-P#```0)@``80```!(`#``/!```0+`````````0`!8`-P0``.`@```R````
M$@`,`*(#```/%@``-P```!(`#`!N`P``("$``.D````2``P`U0,``!2P````
M````$``5`.H#```0L```!````!$`%0!_`P``]!4````````0``P`D0,``%`_
M``!!````$@`,`/0#``!`*```*P```!(`#``G`P``<!T``!D!```2``P`7`,`
M`+!!``#_`0``$@`,`*L#```0(@``_`,``!(`#```;W!E;F1I<@!S=&1E<G(`
M<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M<`!U
M;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`8VQO<V5D:7(`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'9F<')I;G1F`'-T
M<F-H<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R96%D;&EN:P!?
M7V-X85]F:6YA;&EZ90!E>&ET`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<FUD:7(`7U]S=&%T
M7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`%]?;'-T871?=&EM938T
M`&UE;6-P>0!S=')L96X`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D
M:7(`<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB
M8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!L:6)P
M97)L+G-O`&QI8F,N;75S;"UX.#8N<V\N,0!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!X
M<U]I;FET`'!A<E]D:7)N86UE`%]?8G-S7W-T87)T`'-H85]U<&1A=&4`<VAA
M7VEN:70`<&%R7V1I90!?<W1A<G1?8P!P87)?:6YI=%]E;G8`<&%R7V-L96%N
M=7``<&%R7V-U<G)E;G1?97AE8P!?961A=&$`<&%R7V5N=E]C;&5A;@!M>5]P
M87)?<&P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`7V5N9`!P87)?;6MT
M;7!D:7(`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]B87-E;F%M90`O=7-R
M+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```."M```(````Y*T```@```#$
MKP``"````/"O```(````_*\```@`````L```"````!"P```(````P*\```8!
M``#(KP``!@T``,RO```&%P``T*\```8A``#4KP``!BL``-BO```&,```W*\`
M``8R``#@KP``!C@``.2O```&.@``Z*\```8[``#LKP``!CP``/2O```&0@``
M^*\```Y$``#DK@``!P(``.BN```'`P``[*X```<$``#PK@``!P4``/2N```'
M!@``^*X```<(``#\K@``!PD```"O```'"@``!*\```<+```(KP``!PP```RO
M```'#@``$*\```</```4KP``!Q```!BO```'$0``'*\```<2```@KP``!Q,`
M`"2O```'%```**\```<5```LKP``!Q8``#"O```'&```-*\```<9```XKP``
M!QH``#RO```'&P``0*\```<<``!$KP``!QT``$BO```''@``3*\```<@``!0
MKP``!R(``%2O```'(P``6*\```<D``!<KP``!R4``&"O```')@``9*\```<G
M``!HKP``!R@``&RO```'*0``<*\```<J``!TKP``!RP``'BO```'+@``?*\`
M``<O``"`KP``!S$``(2O```',P``B*\```<T``",KP``!S4``)"O```'-@``
ME*\```<W``"8KP``!SD``)RO```'/0``H*\```<^``"DKP``!S\``*BO```'
M0```K*\```=!``"PKP``!T,``+2O```'10``N*\```=&``"\KP``!T<`````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D
M````:+`!``#I@/S___^C\````&:0_Z/\````9I#_HP`!``!FD```````````
M#PL/"P\+9I!FD&:09I!FD(U,)`2#Y/#_<?Q5B>57B<]64^AO`@``@<,!FP``
M48/L+(M!!(E%U(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z"K\__^+@Q`!
M``"#Q`Q04/^S]````.@4____BX,,`0``@\00@#@`#X07`0``BX,@`0``98L`
M@(C2`@```XL'C7`#@\`$B77,/?___S\/AW,!``"#[`S!X`)0Z)#\__^+==2+
M/X/$$(G!B8-@`0``BP:)`8V#_J+__XE!!(N#.`$``(E!"(V#`:/__XE!#(/_
M`0^.0P$``(E-R(U&!(U1$(TTOHUT)@"+"(/`!(/"!(E*_#G&=?&+3<B#QP.#
M[`R-@_AM___'!+D`````:@!1_W7,4/^S9`$``.B!^___@\0@A<`/A(\```"#
M[`S_LV0!``"-?>#HQ?W__XGZB<:-@[RA___HE@(``(/$$(7`='Z#[`S_LV0!
M``#H(?[__^B\^___@\00BT7D92L%%`````^%N````(UE\(GP65M>7UV-8?S#
MZ";[__^)@V0!``"%P`^$C0```(/L#%#HO_O__XN#(`$``(/$$&6+$,:"I@4`
M``#IN_[__X/L#/^S9`$``.A)^___@\00Z5O___^+@UP!``"%P'01@^P,4.C>
M'```@\00Z6?___^)^HV#<:'__^CI`0``B8-<`0``A<`/A$S____KTE!0C8-L
MH?___[/H````4.@%_/__OP0```#IV/[__X/L#&H!Z&']___HNRT``#'MB>"#
MY/!04.@`````@00DYI<``%#H`````%/H,0```('#PY@``(/L$(M$)!AJ`(U0
M!/^S[````/^S)`$``%+_,/^S&`$``.C/_/__@\0H6\.+'"3#9I!FD&:0Z$4!
M``"!PH.8``"-BCP!``"-@CP!```YR'0=BX(4`0``A<!T$U6)Y8/L%%'_T(/$
M$,G#C70F`)##C;0F`````.@%`0``@<)#F```58GE4XV*/`$``(V"/`$``(/L
M!"G(B</!Z!_!^P(!V-'X=!2+DAP!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F
M`````&:058GE4^A=____@</OEP``@^P$@+L\`0```'5#BY,``0``A=)T$8/L
M#/^S*`$``.B-_/__@\00Z#7___^+@_````"%P'02@^P,C8/\XO__4.A<_/__
M@\00QH,\`0```8M=_,G#C;0F`````(VV`````%7H`````%J!PH*7``")Y5/H
MX?[__X'#<Y<``(/L!(N#_````(7`=!F-@T`!``!2:@!0C8/\XO__4.@*_/__
M@\00BUW\R>GV_O__BQ0DPV:055=64^B=_O__@<,OEP``@^P<B50D"(7`#X2R
M````B<&+@_@```"+$(72#X2@````#[8!A,!T!#P]=54Q[8LRA?9T/(E4)`R)
M\(G6B4PD!(G'C;0F`````(/L!%7_="0,5^B*^/__@\00A<!U!H`\+SUT-8M^
M!(/&!(7_==N)_H/$'(GP6UY?7<.-M"8`````B<T/MD4!@\4!A,!T!#P]=?$I
MS>N8C78`BU0D#(GXB?>)QHM$)`@IUXUT+@'!_P*).(/$'(GP6UY?7<.-="8`
MD(/$'#'V6XGP7E]=PXUT)@!6B<93Z+W]__^!PT^6``"![*P```!EH10```")
MA"2D````,<"-1"044%;H4?G__X/$$(7`=3J+5"0<@>(`\```@?H`0```=`B!
M^@"@``!U(H/L"&H"5N@U^/__@\00A<`/E,`/ML#K"HVT)@````"0,<"+E"2<
M````92L5%````'4)@<2D````6U[#Z)\J``!55U:)QE/H*_W__X'#O94``('L
MO````&6A%````(F$)*P````QP(7V=`6`/@!U(8N$)*P```!E*P44````#X4N
M`0``@<2\````6UY?7<-FD(/L#%;H)_C__X/$$(G'A<!TS8/L#%?HM??__X/$
M$(7`#X2R````@'@3+HU0$W4)@'H!`'3=C78`@'@3+@^$M@```(E4)`R#[`Q6
MZ*'W__^+5"0<B<6)%"2)5"0<Z(_W__^-1`4"B00DZ`/Y__^+5"0<B<6-@RBA
M__]25E!5Z'[Y__^#Q!B-1"0D4%7HT/;__X/$$(/X_W00BT0D+"4`\```/0!`
M``!T<(/L#%7H3_?__X/$$(/L#%7HL_?__X/$$(/L#%?H!_?__X/$$(7`#X52
M____C70F`(/L#%?H7_;__XDT).CW]___@\00Z>[^__^-M"8`````@'H!+@^%
M0/___X!Z`@`/A`;____I,?___XVT)@````")Z.B1_O__ZY/H*2D``(VT)@``
M``"-=@!5B<575HG64^BI^___@<,[E```@^PX9:$4````B40D*#'`,<"`.CT/
ME,`!QE;HCO;__X/$$(E$)`2-5"08B>CHS/S__X7`#X0$`0``@^P,B<=0Z&GV
M__^+3"04@\00.<@/@\H```"+1"08P>`"B40D"(N#^````(D$)`^V10"$P`^$
MF@$``#P]#X22`0``B>@/ME`!@\`!A-)T!8#Z/77P*>B+#"2+?"0(@^P,BU0D
M$`,YC400`E#HA/?__X/$$(D'A<!T2HL,)(M\)`B+`8U-`8L4.`^V10"(`CP]
M=1'K$P^V`8/"`8/!`8@"/#UT!(3`=>W&`CTQP(VT)@````"0#[8,!HA,`@&#
MP`&$R77QBT0D'&4K!10````/A1,!``"#Q"Q;7E]=PXVT)@````"0,<"-M@``
M```/MA0&B!0'@\`!A-)U\NO'C;0F`````)"+@_@```"+$(D$)(LZA?\/A,(`
M```Q_XVT)@````!FD(GX@\<!BPRZA<EU](T$A0P```"+BU@!``"%R75CB50D
M#(/L#%#'@U@!```!````Z)SV__^#Q!")P87`#X1>____C02]`````(/L!(E$
M)`Q0BU0D%%)1B4PD'.C!]?__BT0D$(M,)!R#Q!")",=$N00`````B7PD&.F-
M_O__C78`@^P(4%+H]O/__XG!BT0D$(/$$(D(A<D/A`+___^-!+T`````B40D
M".O"C;8`````,<#I>_[__[@(````,?_I4/___^CG)@``C;0F`````)!64^AO
M^?__@<,!D@``@^P$C8-TX?__B[,@`0``4(V#+J'___^S!`$``%!E_S;H;O7_
M_UB-@]NB__]::@!04(V#>('__U"-@TJA__]09?\VZ'SU__^#Q"1;7L.-M@``
M``!3Z!#Y__^!PZ*1``"#[`B-@W3A__]0C8,NH?___[,$`0``4(N#(`$``&7_
M,.@/]?__@\086\.-M"8`````C78`55=64X'L`!```(,,)`"![``0``"##"0`
M@^P<Z+;X__^!PTB1``!EH10```")A"0,(```,<#HEO/__X/L#(V37Z'__U)0
MC8-CH?__4&@!$```C70D)E;H1?3__X/$((U0`8'Z`1````^'T_7__X/X_P^$
MF@```(/L!&@`$```C;PD$Q```%=6Z,3S__^#Q!")Q87`>'N#[`R-0`%0Z+_T
M__^#Q!")QH7`=&8Y^',+C00H.<</@H?U__\Y]W)#@?T!$```#X=W]?__@^P$
M55=6Z"SU___&!"X`@\00BX0D#"```&4K!10```!U*8'$'"```(GP6UY?7<.-
MM"8`````D(T$+SG&<[;I-/7__XUT)@`Q]NO'Z"8E``"-M"8`````Z=O^__^-
MM"8`````C70F`%575E.![``0``"##"0`@>S,````Z(WW__^!PQ^0``"+O"3@
M$```BZPDY!```&6A%````(F$)+P0```QP(U$)"R)1"04B<*-@W&A___HK_C_
M_X/L"&HOB<97Z`+R__^#Q!"%P'0SC8-ZH?__B?KH?OO__XGXBY0DO!```&4K
M%10````/A:@!``"!Q,P0``!;7E]=PXUT)@"0@^P,5>B?\___6EF-BX>A__^)
M3"0445#HS//__X/$$(V+B:'__XG%C8.0HO__B40D&(7M=)B`?0``B4PD'`^$
M]@```(UT)@"0A?9T%8/L"%56Z'+S__^#Q!"%P`^$LP```(/L#%7HKO'__X/$
M$(G"C40%_SG%<A/K)(VT)@````#&``"#Z`$YQ70%@#@O=/&#[`Q5Z(#Q__^#
MQ!")PHE4)!"#[`Q7Z&[Q__^+5"0@@\00C40"`3W_#P``#X<-____@^P(5_]T
M)"A5_W0D+&@`$```C:PDV````%7H^?'__X/$((/``3T`$```#X>*\___@^P(
M_W0D'%7HB_#__X/$$(7`=1"+1"0\)0#P```]`(```'14@^P(_W0D%&H`Z,;R
M__^#Q!")Q87`#X2>_O__@'T```^%#____X7V=`6`/BYT%KH!````C:MOH?__
MZ4O___^-M@````"`?@$`=+;KXHVT)@````"0@^P(:@%5Z&7P__^#Q!"%P'6:
MB>J-@WJA___HT?G__X/L#%7H&/+__X/$$.E$_O__Z-HB``"-M"8`````C70F
M`%93Z%_U__^!P_&-``"#[`R+="08:B]6Z%3O__^%P(U0`0]%\HDT).C4\?__
M@\046U[#C;0F`````(VT)@````!64X'L`!```(,,)`"#[!3H$O7__X'#I(T`
M`(NT)"`0``!EH10```")A"0,$```,<"%]@^$F````(`^``^$CP```(/L#%;H
MYN___X/$$(U0`3'`@?H`$```=UJ#[`A6C70D&%;H^/#__XDT).C`[___@\00
MC40&_SG&<@_K$HUV`,8``(/H`3GP=`6`."]T\8/L"&HO5NB6[O__@\00A<!T
M+SG&<P/&``"#[`Q6Z`_Q__^#Q!"+E"0,$```92L5%````'4@@<04$```6U[#
MC78`@^P,C8-OH?__4.CA\/__@\00Z]#HIB$``(VT)@````!55U;H,1$``('&
MP(P``%.#["QEH10```")1"0<,<"-7"08BZ[X````C;Z+H?__B=J)^.A9]?__
MA<!T+HM4)!B+10"-!)"+4`2)$(72=.!FD(M0"(/`!(D0A=)U](G:B?CH*_7_
M_X7`==*+KO@```"-OI2A__^)VHGXZ!+U__^%P'0OBU0D&(M%`(T$D(M0!(D0
MA=)TX(UV`(M0"(/`!(D0A=)U](G:B?CHX_3__X7`==&+KO@```"-OIRA__^)
MVHGXZ,KT__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U
M](G:B?CHF_3__X7`==&+KO@```"-OJ6A__^)VHGXZ(+T__^%P'0OBU0D&(M%
M`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CH4_3__X7`==&-AJRA
M__^+OO@```")!"2+!"2)VN@V]/__A<!T+(M4)!B+!XT$D(M0!(D0A=)TX(M0
M"(/`!(D0A=)U](L$)(G:Z`KT__^%P'74BZ[X````C;Z\H?__B=J)^.CQ\___
MA<!T-HM4)!B+10"-!)"+4`2)$(72=."-M"8`````C78`BU`(@\`$B1"%TG7T
MB=J)^.B[\___A<!URHV&<:'__XN^^````(E$)`2+1"0$B=KHG//__X7`=#.+
M5"08BP>-!)"+4`2)$(72=-^-M@````"+4`B#P`2)$(72=?2+1"0$B=KH:?/_
M_X7`=<V-ALBA__^+OO@```")1"0,BT0D#(G:Z$KS__^%P'0QBU0D&(L'C020
MBU`$B1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`R)VN@9\___A<!USXV&TJ'_
M_XN^^````(E$)`B+1"0(B=KH^O+__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-
M="8`BU`(@\`$B1"%TG7TBT0D"(G:Z,GR__^%P'7/BZ[X````C;[<H?__B=J)
M^.BP\O__A<!T-8M4)!B+10"-!)"+4`2)$(72=."-M"8`````9I"+4`B#P`2)
M$(72=?2)VHGXZ'OR__^%P'7+BZ[X````C;YZH?__B=J)^.AB\O__A<!T+XM4
M)!B+10"-!)"+4`2)$(72=."-=@"+4`B#P`2)$(72=?2)VHGXZ#/R__^%P'71
MB=J-AN:A___H(O+__X7`=`N)PHM$)`CH`_7__XG:C8;WH?__Z`;R__^%P'0-
MB<*-A@FB___HY?3__XG:C884HO__Z.CQ__^)PH7`="N+1"0$Z,GT__^+1"0<
M92L%%````'4SBP0D@\0LC9;\HO__6UY?7>FG]/__B=J-AB2B___HJO'__X7`
M=,V)PHM$)`SHB_3__^O`Z*,=``"-="8`Z#`-```%PX@``(/L'&6+%10```")
M5"0,,=*-5"0(C8#(H?__Z&?Q__^%P'0K#[80@/HP#Y3`A-(/E,()T(/P`0^V
MP(M4)`QE*Q44````=0R#Q!S#C70F`#'`Z^?H/AT``(VT)@````"-M"8`````
MD%/HP.___X'#4H@``(/L"(U$)!2#[`10_W0D&(N#"`$``/\PZ$CL___'!"3_
M````Z)SL__^-M"8`````C70F`)!55U93C9PD``#__X'L`!```(,,)``YW'7R
M@^PLZ&7O__^!P_>'``")Q66A%````(F$)!P``0`QP&H":@!J`%7HK.G__X/`
M_X/2_XE$)!B+="08B=>)5"0<P?\?,?@I^#'2)?__```Q^C'X*?@9^HM\)!PI
MQHET)!@9UXE\)!R#Q!"-="04A?\/B+L```"-=@!J`/]T)!#_="005>A0Z?__
M@\00(="#^/\/A+4```"#[`1H"``!`%95Z"/J__^#Q!"#^/\/A(L```"#^`=V
M4HU$!O@Y\')*C3TL`0``ZPEFD(/H`3GP<CF+$(M(!#,4'S-,'P0)RG7I*?"9
M`T0D"!-4)`R+C"0<``$`92L-%````'5@@<0L``$`6UY?7<.-=@"!1"0(``#_
M_XM4)`B#5"0,_XM,)`R)T(G*-0``___WT@G0#X5(____N/____^Z_____^NN
M@^P,C8-"HO__4.A=_O__@^P,C8,UHO__4.A._O__Z'@;``"-M"8`````9I!3
MZ`#N__^!PY*&``"#[`CH'.G__X/L#%#H\^G__X/$$(7`=`*+`(/$"%O#C70F
M`)!55U93Z,WM__^!PU^&``"#["QEH10```")1"0<,<"-5"08BVPD0(V[3J+_
M_XGXZ/WN__^%P'0'@#@`B<9U(HM$)!QE*P44````#X6<````B>J#Q"R)^%M>
M7UWIP?'__Y"#[`A54.B&Z?__@\00A<!T'XM$)!QE*P44````=6V#Q"Q;7E]=
MPXVT)@````"-=@"#[`Q5Z$?H__^)-"2)1"0<Z#OH__^+5"0<C40"`HD$).BK
MZ?__B30DB<*-@X>A__]0C8.0HO__55!2B50D+.@=ZO__@\0@BU0D#(M$)!QE
M*P44````#X1F____Z$\:``!55U93Z-WL__^!PV^%``"!["P!``"+A"1``0``
MC7PD((GZB40D#(V+9:+__V8/;L&-BQ^B__]EH10```")A"0<`0``,<"-@V^A
M__]F#V[)C8L"HO__QX0DN`````````!F#V[0C8-RHO__9@]BPF8/;MB-@VJB
M___'A"3D`````````&8/;N!F#V++9@_6A"2P````9@]NP68/8L2-@WNB__^-
MBW:B___'A"3(`````````&8/;,%F#V[HC8-QH?__#Q&$)-0```!F#V[!9@]B
MQ8E$)!AF#]:$),````#H7>W__X7`=`F`.``/A5@$``#H&^?__X/L#%#H\N?_
M_X/$$(7`#X0'`@``BRB%[0^$_0$``(/L#%7HU.;__X/$$(/L#(U$``%0Z$3H
M__^#Q!")Q@^V10")="0(A,!T-8V+A*+__XE\)`2)[XGUB<Z-=@"#[`0/ML"#
MQP%05E6#Q0+HG.C__P^V!X/$$(3`=>*+?"0$C;0DT````(V#":+__^L1C;0F
M`````(M&!(/&!(7`="Z)^NBG[/__B<6%P'3I@#@`=.3H=^W__X7`=-N#[`Q5
MZ,KG__^#Q!")Q87`=3&0C;0DL````(LNA>UT(X!]```/A"D!``")Z.A"[?__
MA<`/A?H```"+;@2#Q@2%[77=@^P,5>CWY?__6O]T)!2)QNCKY?__C;0&!`0`
M`(DT).A<Y___B40D%(G!6(V#B:+__UK_="004(V#B:'__XE$)!A0C8..HO__
M58G-4%'HON?__X/$&&C``0``5>B`YO__@\00@_C_=1#H,^;__XL`@_@1#X6R
M`@``@^P(5_]T)!#H*^;__X/$$(G%A<!U%(M$)#`E`/```#T`0```#X3M````
M_W0D!(M$)!#_,(V#0*/__U"+@P@!``#_,.APY?__@\00,?:+A"0<`0``92L%
M%`````^%$P0``('$+`$``(GP6UY?7<.-M"8`````C78`@^P,@\8$5>B4YO__
M@\00B<6%P`^$SO[__^GR_O__9I`Q[>GI_O__C;0F`````&:0BX0DP````(VT
M),````"%P'0@C;8`````B?KH$>O__X7`=`6`.`!U,(M&!(/&!(7`=>:#[`R-
MJUZB__]J#>@>YO__@\00B<:)1"0(N%,```#IV/W__XUV`(/L#%#H#^;__X/$
M$(G%A<!TONF4_?__BT0D.(E$)!#HA.3__SE$)!`/A?S^__^+1"0P)?\!```]
MP`$```^%Z/[__X/L#%;HO>7__XGZB<:-@UFB___H?NK__X/$$(7`#X2C`0``
M@^P(4(M$)!C_,.AD\?__B40D((/$$(7`#X2%`0``@^P,_W0D'.CYX___@\00
MB<*#^`-V/X/L"(V#EZ+__U"+1"0<C400_(E4)"A0Z(/E__^#Q!"%P'4<BU0D
M'(/Z!`^$5`(``(M$)!"`?!#[+P^$10(``(GZC;O(H?__B?CH\>G__X7`#X0I
M`0``#[8`A,`/A!X!```\,`^$%@$``(V3_*+__XGXC;O;HO__Z+/L___H7N/_
M_X/L"%=0C8.[HO___W0D&/]T)!A05NADY?__@\0@C8/)HO__B40D#.LRC70F
M`)#HV^/__X,X$74YZ"'C__^#Q0&#[`1755#_="08_W0D&/]T)"16Z";E__^#
MQ""#[`AHP`$``%;HY>/__X/$$(/X_W2]@^P,_W0D$.AQX___BT0D*(GRZ";L
M__^)-"3H_OG__X/$$.F;_?__@^P,4/]T)!2+1"0@_S"-@P2C__]0BX,(`0``
M_S#HY.+__X/$(.EO_?__C70F`(/L#%")1"04Z+OY__^+1"04B00DZ!_D__^#
MQ!")QNE*_?__C70F`)"+1"0,BP")1"00Z6S^__^0@^P(:@#_="0<Z*+C__^#
MQ!"%P`^$T?[__XE$)`SHOO?__XE$)!")5"04A=(/B+C^__^#P/9J`(/2_U)0
MBTPD&%&)3"0<Z(;A__^#Q`QJ!HV$)/4```!0BTPD&%&)3"0<Z%OB__^#Q!"+
M3"0,@_@&#X7L````@;PD[0````!#04,/A63^__]F@;PD\0```$A%#X54_O__
M:@"+1"04BU0D&(/`SH/2_U)048E,)!SH'N'__X/$#&HHC;PD^P```%>+3"08
M4>CWX?__@\00@_@H#X6,````QH0D&P$```"-@]NB__^#[`A0C8.LHO__5_]T
M)!C_="084%;H@^/__X/$(.EN_O__BT0D#(M0!(72#X2L_?__@^P,4HE4)!SH
M3^'__X/$$(/X`P^&D_W__X/L"(V+G*+__U&+5"08C40"_%#HV^+__X/$$(M4
M)`R%P`]%5"00B50D$.ED_?__Z&X3``"#[`R-@Z&B__]0Z##V__]55U93Z.WE
M__^!PW]^``"#["QEH10```")1"0<,<"-?"08B?J+LR`!``!EBRX/MD5DB$5E
MC8.LH?__Z!'G__^%P'0)@#@Q#X1$`0``Z&_Q__]EBRZ-@]JB__]J`VH!4%7H
M^^#__X/$$(G%A<!T*8/L!(V#W*+__U"+10S_,&7_-NBKXO__BT4,@\00BP#V
M0`I`#X5!`0``C8/AHO__:@-J`5!E_S;HMN#__X/$$(G%A<!T*8GZC8-ZH?__
MZ)#F__^%P`^$V````(/L!%"+10S_,&7_-NA7XO__@\00@^P$C8/CHO__:@%0
M9?\VZ`#?__^#Q`R-D_BB__]24&7_-N@MXO__98L&B?K&0&4`C8-QH?__Z#GF
M__^#Q!")@UP!``"%P'0\@^P(:,`!``!0Z*[@__^#Q!"-4`&#^@%V"8/X$0^%
MI@```(M$)!QE*P44````#X7)````@\0L6UY?7<.0@^P,_[-@`0``Z*+W__^#
MQ!")@UP!``"%P'6I@^P,C8.4H___4.@&X/__C;8`````@'@!``^$NO[__^FM
M_O__D.A[Z___A<!T9X/L!%"+50R)1"04_S)E_S;H<N'__XM$)!R)!"3HMM__
M_X/$$.D*____C;8`````@^P(4&7_-NCLW?__@\00Z:O^__]0BX-@`0``_[-<
M`0``_S"-@[BC__]0Z(G?__^-M"8`````9I"+@V`!``"#[`3_,.FL_O__Z#H1
M``"-M"8`````C70F`%=64^B^X___@<-0?```@^P09:$4````B40D##'`C50D
M"(MT)""-@\BA___H\.3__X7`=!L/MA"`^C`/E,"$T@^4P@C0=0F%]G0%@#X`
M=1F+1"0,92L%%````'5D@\006UY?PXUT)@"0@^P,5N@O[O__B<=86FHO5^A3
MW?__A<"-4`$/1?J)/"3HT]___X/$#(V3B:+__VH$4E#H<=W__X/$$(7`=:F+
M1"0,92L%%````'4-@\00B?!;7E_IT.7__^AJ$```BP0DPXLT),-FD)!55U93
MB<.!['P!``")1"00C4PD+&6A%````(F$)&P!```QP(UT)@"0BU2#'`_*B12!
M@\`!@_@0=>^+3"0PBW0D8(U4)#2+;"1DBT0D:(E,)`B-C"0T`0``BUPD+(E,
M)`SK"HVV`````(E,)`B+"HG'BT(8@\($,<@Q\(GNB?TQV(M<)`C1P(E"-#E4
M)`QUV8MT)!"+1"0LBQZ+5A"+;@B+?@R)5"0<C90"F7F"6HG8BTX$P<`%B?Z)
M;"04`<*)Z(E,)`PQ^(ET)!@AR,')`C'XB=\!PHGHB7PD",'/`C'((=B+7"0P
M,>B-M!Z9>8):B=,!QL'#!0'>B<LQ^XG8BUPD-"'0P<H",<B-G!V9>8):BVPD
M.`'#B?#!P`6-C"F9>8):BVPD/`'#B?@QT"'PP<X",?B-O"^9>8):BVPD0`'(
MB=G!P04!R(G1,?$AV3'1C90JF7F"6HML)$0!^8G'P<<%P<L"`?F)]S'?(<<Q
M]XVT+IEY@EJ+;"1(`?J)S\''!0'ZB<>)V,'/`C'X(<C!R0(QV(V<*YEY@EJ+
M;"1,`?")UL'&!0'PB<Z)^3'Q(=$Q^8V\+YEY@EJ+;"10`=F)P\'#!0'9B=.)
M\L'+`C':(<(Q\HVT+IEY@EJ+;"14`?J)S\''!0'ZB<>)V,'/`C'X(<C!R0(Q
MV(V<*YEY@EJ+;"18`?")UL'&!0'PB<Z)^3'Q(=$Q^8V\+YEY@EJ+;"1<`=F)
MP\'#!0'9B=.)\L'+`C':(<(Q\HVT+IEY@EJ+;"1@`?J)S\''!0'ZB<>)V,'/
M`C'X(<C!R0(QV(V<*YEY@EJ+;"1D`?")UL'&!0'PB<Z)^3'Q(=$Q^8V\+YEY
M@EH!V8G#P<,%`=F)TXGRP<L",=HAPL'(`C'RB<6)V`'ZB<\QZ,''!2'(P<D"
M`?J+?"1H,=B-M#Z9>8):B=<!\,''!0'XB>\QSXG^BWPD;"'6P<H",>Z-O#N9
M>8):B<,!]\'#!8MT)'`!WXG+,=.-M#69>8):BVPD="'#P<@",<N-C"F9>8):
MBVPD>`'>B?O!PP4!WHG3,<,A^S'3P<\"C90JF7F"6@'+B?'!P04!RXG!,?DA
M\<'.`C'!`=&)VL'"!0'1BU0D?(V$$*'KV6Z)^C'R,=K!RP(!PHG(P<`%`<*+
MA"2`````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDA````,'/`HVT#J'K
MV6Z)V3'Y,='!R@(!\8G&P<8%`?&)UHN4)(@```"-G!.AZ]ENB?HQ\C'"`=J)
MR\'#!0':B<.+A"2,````P<L"C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPD
MD````,'/`HVT#J'KV6Z)V3'Y,='!R@(!\8G&P<8%`?&)UHN4))0```"-G!.A
MZ]ENB?HQ\C'"`=J)R\'#!0':B<.+A"28````P<L"C;P'H>O9;HGP,=@QR`'X
MB=?!QP4!^(G/BXPDG````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?'!R@*)
MUHN4)*````"-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':B<.+A"2D````P<L"C;P'
MH>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDJ````,'/`HVT#J'KV6Z)V3'Y,='!
MR@(!\8G&P<8%`?&)UHN4)*P```"-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':B<.+
MA"2P````P<L"C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDM````,'/`HVT
M#J'KV6Z)V3'Y,='!R@(!\8G&P<8%`?&)UHN4)+@```"-G!.AZ]ENB?HQ\C'"
M`=J)R\'#!0':B<.+A"2\````P<L"C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/
MBXPDP````,'/`HVT#J'KV6Z)V3'Y,='!R@(!\8G&P<8%`?&)UHN4),0```"-
MG!.AZ]ENB?HQ\C'"`=J)R\'#!0':B<.+A"3(````P<L"B=V-G`>AZ]ENB?`Q
MZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"3,````C;0^W+P;
MCXG'`?/!QP6)S@'[B<\AU@G7(<?!R`()_HN\)-````"-O#W<O!N/B=4!]XG>
M"<7!Q@4AW<'+`@'WB=8AQ@GNBZPDU````(V,*=R\&X^)W8G#`<Z)^0GKP<$%
M(?L!SHG!(>D)V8N<)-@```"-G!K<O!N/B?(!R\'"!<'/`@'3B>H)^HG1B>HA
M\2'ZP<X""<J+C"3<````C8P(W+P;CXG8`='!P`6)^@'!"?*)^"':(?#!RP()
MT(N4).````"-E!7<O!N/`<*)R,'`!0'"B?`)V(G%B?`AS2'8">B+K"3D````
MC;POW+P;CXG=`?B)U\''!0'XB<^)V<'/`@G](?DAU0GIBZPDZ````(VT+MR\
M&X\!\8G&P<H"P<8%`?&)UHGZ"?*)U8GZ(<4A\@GJBZPD[````(V<*]R\&X\!
MVHG+P<,%`=J)PXGPP<L""=B)Q8GP(<TAV`GHBZPD\````(V\+]R\&X^)W0'X
MB=?!QP4!^(G/B=G!SP()_2'Y(=7!R@()Z8NL)/0```"-M"[<O!N/`?&)QL'&
M!0'QB=:)^@GRB=6)^B'%(?()ZHNL)/@```"-G"O<O!N/`=J)R\'#!0':B<.)
M\,'+`@G8B<6)\"'-(=@)Z(NL)/P```"-O"_<O!N/B=T!^(G7P<<%`?B)SXG9
MP<\""?TA^2'5P<H"">F+K"0``0``C;0NW+P;CP'QB<;!Q@4!\8G6B?H)\HG5
MB?HAQ2'R">J+K"0$`0``C9PKW+P;CP':B<O!PP4!VHG#B?#!RP*)W8GS">LA
MZ"'+"=B+G"0(`0``C9P?W+P;CP'8B=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*
M`@G[B[PD#`$``(VT/MR\&X^)QP'SP<<%B<X!^XG/(=8)UR''P<@""?Z+O"00
M`0``C;P]W+P;CP'^B=_!QP4!_HG7"<>)_8G7(=TAQ\'+`@GOBZPD%`$``(V,
M*=R\&X\!^8GWP<<%`?F)QPG?B?V)QR'U(=\)[XNL)!@!``"-E"K<O!N/BVPD
M"`'ZB<_!S@+!QP4!^HN\)!P!``"-A#C6P6+*B=\Q]S'/P<D"`<>)T,'`!0''
MBX0D(`$``(V<`];!8LJ)\#'(,=`!V(G[P<,%`=B)TXN4)"0!``#!RP*-E!;6
MP6+*B<XQWC'^P<\"`=:)PL'"!0'6BY0D*`$``(V,$=;!8LJ)VC'Z,<+!R`(!
MRHGQP<$%`<J)P8N$)"P!``"-A`/6P6+*B?LQRS'S`<.)T,'`!0'#BX0D,`$`
M`,'.`HV\!];!8LJ)R#'P,=`!^(G?P<<%`?B)UXN4)#0!``#!SP*-E!'6P6+*
MB?$Q^3'9P<L"`=&)PL'"!0'1BY0D.`$``(VT%M;!8LJ)^C':,<+!R`(!\HG.
MP<8%`?*)QHN$)#P!``"-A`?6P6+*B=\Q]S'/P<D"`<>)T,'`!0''BX0D0`$`
M`(V<`];!8LJ)\#'(,=`!V(G[P<,%`=B)TXN4)$0!``#!RP*-E!;6P6+*B<XQ
MWC'^P<\"`=:)PL'"!0'6BY0D2`$``(V,$=;!8LJ)VC'Z,<+!R`(!RHGQP<$%
M`<J)P8N$)$P!``"-A`/6P6+*B?LQRS'SP<X"`<.)T,'`!0'#BX0D4`$``(V\
M!];!8LJ)R#'P,=`!^(G?P<<%`?B)UXN4)%0!``#!SP*-E!'6P6+*B?$Q^3'9
MP<L"`=&)PL'"!0'1BY0D6`$``(VT%M;!8LJ)^C':,<(!\HG.P<@"P<8%`?*)
MQHN$)%P!``"-A`?6P6+*B=\Q]S'/P<D"`<>)T,'`!0''BX0D8`$``(V<`];!
M8LJ)\#'(,=#!R@(!V(G[P<,%`=B+G"1D`0``C;0>UL%BRHG+,=,Q^\'/`@'S
MB<;!Q@4!\XNT)&@!``"-M#76P6+*B=T!SHG1P<4%,?DQP<'(`@'QBW0D$(TL
M*8M,)`QF#V[%BVPD%`'+C0PHBT0D&&8/;MMF#V[)9@]BPXT,.&8/;M%F#V+*
M9@]LP0\1!HM$)!P!T(E&$(N$)&P!``!E*P44````=0N!Q'P!``!;7E]=P^AD
M!```C70F`)!3Z/#6__^!PX)O``"#[!1J8.AJT___9@]O@XCA__^Y\.'2PS';
MB4@0B5@4QT`8`````,=`7``````/$0"#Q!A;PXVT)@````"-M"8`````D.B@
M\___!3-O``!55U93@^P<BU0D,(M\)#B)1"0(BT0D-(M:&(T,_0`````#2A2-
M<AR)2A2)^8/3`,'I'0'9B4H8BTI<A<ET<;U`````C7(<*<TY_0]/[P'Q.<$/
M@R<!``"-'"DYV`^"J-/__XT<*(E<)`R)5"0P@^P$55!1BUPD&.A*T___BU0D
M0(GH@\00`T)<B4)<@_A`=`Z#Q!Q;7E]=PXVV`````(G0*>_H__+__XM$)`R+
M5"0P@_\_#XZ(````C6A`B<.-0ER)?"0XB40D#(GOBVPD.(E4)##K2V:0BT0D
M##G##X(5`0``B7PD"/,/;P.+1"0P@^U`@\-`@\=`#Q$&\P]O2]`/$4X0\P]O
M4^`/$58@\P]O6_`/$5XPZ(SR__^#_3]^%SG><K.)?"0(.?-SNSG^<[?IUM+_
M_V:0BU0D,(M$)`B)[SG&<BHY\',+C0PX.<X/@K?2__^#_P1S1H7_=7J)>ER#
MQ!Q;7E]=PXVT)@````"-##XYR'/>Z9#2__^-="8`C1PHB5PD##G(#X/<_O__
M.=D/@]3^___I<-+__XUT)@"+"(E*'(M,./R)3#[\C4X$@^'\*<XI\`'^@^;\
M@_X$<IV#YOPQVXLL&(DL&8/#!#GS<O.)>ESKB0^V"(A*'/?'`@````^$=/__
M_P^W1#C^9HE$/O[I9?___^D.TO__C;0F`````(UV`%575NB1\?__@<8@;0``
M4X/L'(M<)#2+?"0PBVL8BTL4#\V)Z(G-B00DB<@/S<'H`XEL)`2-:QR#X#^-
M4`'&1`,<@(/Z.`^.]0```+A`````C4P5`"G0="(QTJ@!=`RZ`0```,8!`#G"
M<Q#&!!$`QD01`0"#P@(YPG+PB=CH'_'__V8/[\`/$4,<#Q%%(`\111`/$44H
M\P]^#"2)V&8/UDM4Z/KP__^+`X/L#,'H&(@'BP/!Z!"(1P&+`XAG`HL#B$<#
M#[9#!XA'!`^W0P:(1P6+0P2(9P:+0P2(1P</MD,+B$<(#[=#"HA'"8M#"(AG
M"HM#"(A'"P^V0P^(1PP/MT,.B$<-BT,,B&<.BT,,B$</#[9#$XA'$`^W0Q*(
M1Q&+0Q"(9Q*+0Q"(1Q-3B?/H[L[__X/$+%M>7UW#C;8`````N#@```"-3!4`
M*="#^`0/@HP```"-403'`0````"#XOS'1`'\`````"G1`<B#X/R#^`0/@AW_
M__^)P8UH_X/A_,'M`HE,)`RY!````(/E`<<"`````#G!#X/X_O__A>UT&,="
M!`````"+1"0,N0@````YP0^#W/[__XM$)`S'!`H`````QT0*!`````"#P0@Y
MP7+JZ;W^__^-M"8`````D(7`#X2M_O__Q@$`J`(/A*+^__\QTF:)5`'^Z9;^
M__]5B>53Z([2__^!PR!K``!0Z.S.__]:6UW#@^P,@\0,PP``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`
M4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`'!A
M<BT`)7,E<R5S)7,`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#8Q`"UE`"TM`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T
M7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A
M8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`]
M(")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H
M*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I
M>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M
M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E
M96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD
M<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=
M*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M
M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R
M;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A
M;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA
M9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I
M+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D
M8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S
M*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S
M*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B
M=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").
M(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES
M("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@
M/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L
M(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S
M="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F
M=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L
M97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM
M;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M
M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-
M04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I
M;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A
M<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;
M(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:
M25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A
M9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E
M<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\
M+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@
M("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L
M("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C
M*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y
M(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO
M72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN
M97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT
M9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L
M("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T
M:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO
M=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D
M;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B
M7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P
M+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B
M*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O
M9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q
M6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT
M<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D
M97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C
M86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`]
M(")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P
M<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=
M.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^
M/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*
M<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<
M,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F
M:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M
M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*
M=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL
M;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA
M;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S
M>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?
M)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB
M4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``0T%#2$4``'!E<FQX
M<VDN8P```````````````2-%9XFKS>_^W+J8=E0R$`$;`SL0`0``(0```*!_
M__\L`0``((/__U`!``!`@___;`0``$*#__^@!0``1(/__SP-``!0@____`L`
M`#"'__]D`0``$(C__]P!``"@B/__*`(``""*___8`@``8(S__U@#``#`C/__
MJ`,```"-___4`P``(([__X@$```PCO__G`0``'"0__^\!0``L)#__^P%``"@
MD?__9`8``*"5__^D!@``$);__\`&``!0EO__Z`8``-"7__^8!P```)C__\0'
M``#PF/__/`@``."?__^H"@``$*+__Y`+``#5HO__1`P``-FB__]8#```X*+_
M_VP,``#@KO__L`P``#"O___4#```0+'__U@-```_L___J`T``!0`````````
M`7I2``%\"`$;#`0$B`$``"`````<````;'[__X`#````#@A&#@Q*#PMT!'@`
M/QH[*C(D(A````!`````R('__Q@`````````=````%0```#$A?__W`````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.,`))#C1!#CA$#CQ!#D!(#C!9"@X40\,.
M$$'&#@Q!QPX(0<4.!$@+=`H.%$/##A!!Q@X,0<<."$'%#@1&"T,.%$/##A!#
MQ@X,0<<."$'%#@0`2````,P````LAO__D`````!!#@B&`D,.#(,#40ZX`50.
MO`%!#L`!2`ZP`6$.N`%"#KP!00[``4@.L`%J"@X,0<,."$'&#@1!"P```*P`
M```8`0``<(;__W8!````00X(A0)!#@R'`T$.$(8$0PX4@P51#M`!<@H.%$'#
M#A!!Q@X,0<<."$'%#@1#"T,.W`%!#N`!2`[0`4D.W`%!#N`!2`[0`6L.W`%!
M#N`!<`[D`4$.Z`%!#NP!00[P`4@.V`%%#MP!00[@`4@.T`%8#MP!00[@`4@.
MT`%##MP!00[@`4@.T`%##MP!00[@`4@.T`%/#MP!00[@`5`.T`$`?````,@!
M``!`A___.`(```!!#@B%`D,.#(<#00X0A@1##A2#!4X.3%<.4$@.0%H.3$,.
M4$P.0`).#DQ+#E!(#D`"9`H.%$'##A!!Q@X,0<<."$'%#@1)"P)D#DQ!#E!2
M#D!4#D1%#DA%#DQ!#E!4#D!9#DA!#DQ!#E!.#D````!,````2`(```")__]:
M`````$$."(8"00X,@P-.#A!-#A1,#AA!#AQ##B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ##C!(#@Q!PPX(0<8.!````"@```"8`@``$(G__S8`````00X(@P).
M#A!'#A1,#AA!#AQ)#B!(#@A!PPX$E````,0"```DB?__&0$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!48.E"!*#I1`1PZP0&(.O$!'#L!`00[$0$<.R$!%#LQ`
M10[00$@.L$!;#K1`10ZX0$@.O$!!#L!`2`ZP0$D.O$!$#L!`2`ZP0&@.M$!!
M#KA`00Z\0$$.P$!,#K!`5@H.%$/##A!!Q@X,0<<."$'%#@1)"P`8````7`,`
M`,Q^__\"``````ZP0(,%A0*&!(<#$````'@#``"0B?__!0```````````0``
MC`,``(R)__\U`@```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($H.X"$"0`[H
M(4(.["%##O`A2`[@(6T*#A1!PPX00<8.#$''#@A!Q0X$1@M##NPA00[P(48.
M["%!#N@A2P[L(4$.\"%(#N`A<`[H(4$.["%!#O`A2`[@(4L.["%!#O`A2`[@
M(64.["%!#O`A2`[@(4D.["%!#O`A3`[@(5(.Z"%!#NPA1`[P(4$.]"%$#O@A
M10[\(4@.@")(#N`A40[H(40.["%!#O`A2`[@(5<.Z"%$#NPA0@[P(4@.X"$"
M1@[H(4(.["%!#O`A2`[@(50.["%!#O`A2`[@(0```!@```"0!```FGW__P(`
M````#N`A@P6%`H8$AP,L````K`0``*R*__\R`````$$."(8"00X,@P-.#AA&
M#AQ!#B!8#@Q!PPX(0<8.!`!T````W`0``+R*___I`````$$."(8"00X,@P-&
M#HP@1PZ@('4.K"!!#K`@2`Z@(%`.J"!!#JP@10ZP(%`.H"!?#J@@0@ZL($$.
ML"!(#J`@3@ZL($$.L"!(#J`@5@H.#$'##@A!Q@X$1`M##JP@1PZP($@.H"``
M```\````5`4``#2+___\`P```$$."(4"00X,AP-!#A"&!$P.%(,%0PY``[@#
M"@X41\,.$$'&#@Q!QPX(0<4.!$4+&````)0%``#TCO__80````!-#B`"1@H.
M!$4+`"0```"P!0``2(___S0`````00X(@P).#A!'#A1!#AA$#AQ(#B````"L
M````V`4``&"/__]W`0```$$."(4"00X,AP-!#A"&!$$.%(,%1PP#E(`$3@T$
M0P[`@`1>#L2`!$(.R(`$0@[,@`1!#M"`!`)"#L"`!%$.Q(`$1`[(@`1$#LR`
M!$$.T(`$2`[`@`1.#L2`!$4.R(`$00[,@`1!#M"`!$@.P(`$`E@*#A1!PPX0
M0<8.#$''#@A!Q0X$1`MW"@[,@`1'#M"`!$4+0PH.S(`$1P[0@`1%"R@```"(
M!@``,)#__RL`````00X(@P).#A!(#AQ!#B!(#A!)#@A!PPX$````=````+0&
M```TD/__\`````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.0`)""@X40\,.$$'&
M#@Q!QPX(0<4.!$8+0PY(00Y,00Y02`Y`5`H.%$'##A!!Q@X,0<<."$'%#@1+
M"T,.3$$.4&T.5$<.6$$.7$$.8$P.0```:`(``"P'``"LD/__\`8```!!#@B%
M`D$.#(<#00X0A@1!#A2#!5$.P`("XP[,`D$.T`)(#L`"50[,`D$.T`)(#L`"
M0P[,`D4.T`)(#L`"9`[$`D<.R`)!#LP"00[0`DX.P`("1@[,`D$.T`)(#L`"
M>@[,`D$.T`)&#LP"1`[0`ET.S`)'#L@"1`[,`D$.T`)+#M0"1P[8`D,.W`)!
M#N`"2`[(`D4.S`)!#M`"2`[``E@.R`)!#LP"1`[0`D@.P`)>#L0"1@[(`D<.
MS`)(#M`"2`[``EP*#A1#PPX00<8.#$''#@A!Q0X$2PM##LP"1`[0`D@.P`("
M5@[,`D@.T`)(#L`"5@[,`D$.T`)(#L`">0[,`D$.T`)7#L`"2P[(`D$.S`)&
M#M`"3`[``DL.S`)$#M`"2`[``DH.R`)'#LP"30[0`D@.P`("90[(`D$.S`)!
M#M`"2@[4`D0.V`)!#MP"00[@`D@.P`)F#L0"00[(`D$.S`)!#M`"1`[4`D0.
MV`)$#MP"00[@`D@.P`)##L@"10[,`D$.T`)(#L`"2`[,`D0.T`);#L`"2`[,
M`D$.T`)$#M0"1@[8`D<.W`)(#N`"2`[``DP.S`)!#M`"6`[``E\.R`)"#LP"
M1`[0`D@.P`)F#L0"1`[(`D$.S`)%#M`"3`[$`D(.R`)(#LP"10[0`DP.P`)P
M#L0"3P[(`D$.S`)!#M`"3`[$`D(.R`)(#LP"10[0`D@.P`):#L@"00[,`D<.
MT`)$#M0"1`[8`D$.W`)!#N`"2`[``E<.S`)!#M`"3`[``DP.R`)'#LP"20[0
M`D@.P`)<#LP"1P[0`@#D````F`D``#"5__\E`@```$$."(4"00X,AP-!#A"&
M!$$.%(,%3@Y``DH.1$(.2$$.3$$.4$@.0$D.1$<.2$4.3$,.4$L.0%0.1$(.
M2$$.3$,.4$@.0%X.1$$.2$4.3$,.4$@.0$,.1$@.2$$.3$,.4$@.1$<.2$$.
M3$,.4%P.0$T.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!Q0X$0@M#"@Y,
M1@Y02`Y`30Y,1PY02PM<#D1!#DA)#DQ##E!4#D!.#DA!#DQ##E!(#D!&"@Y$
M3`Y(0@Y,1PY03@M)"@Y$0@Y(10L`:````(`*``!XEO__Q0````!!#@B'`D$.
M#(8#00X0@P1.#B`"3@H.$$'##@Q!Q@X(0<<.!$8+0PXL00XP2`XL00XH0@XL
M00XP6`XD2`XH00XL00XP2`X@5`H.$$/##@Q!Q@X(0<<.!$4+````1````.P*
M``!,=___-`(```!$#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#
M7P$*P0P!`$'#0<9!QT'%0PP$!$$+$````#0+``")EO__!``````````0````
M2`L``'F6__\$`````````$````!<"P``;);___L+````00X(A0)!#@R'`T$.
M$(8$00X4@P5(#I`#`^4+"@X40<,.$$'&#@Q!QPX(0<4.!$$+````(````*`+
M```HHO__00````!!#@B#`DX.'$(.(&X."$'##@0`9````,0+``!4HO__!@(`
M``!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`)I#C1!#CA!#CQ!#D!2#C!."@X4
M0<,.$$'&#@Q!QPX(0<4.!$<+`L0*#A1!PPX00<8.#$''#@A!Q0X$2`L````8
M````+`P```!V__\"``````XP@P6%`H8$AP,`3````$@,``#@H____P$```!!
M#@B%`D$.#(<#00X0A@1,#A2#!4,.,`*9#CP"@`Y`2@X40<,.$$'&#@Q!QPX(
M0<4.!$<.,(,%A0*&!(<#```@````F`P``(^E__\9`````$$."(4"0@T%08,#
M4\-!Q0P$!```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````%`7``#@%@```0````D#```!````%`,``!T```!$!```#``````0
M```-````R$,``!D```#@K0``&P````0````:````Y*T``!P````$````]?[_
M;Q@"```%````%`D```8```#T`@``"@```&($```+````$````!4`````````
M`P```-BN```"````N`$``!0````1````%P```!@.```1````>`T``!(```"@
M````$P````@````>````"````/O__V\!```(^O__;P<`````````````````
M````````````````````````````````````````Z*T`````````````)A``
M`#80``!&$```5A```&80``!V$```AA```)80``"F$```MA```,80``#6$```
MYA```/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``=A$``(81``"6
M$0``IA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F$@``-A(``$82
M``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82``#F$@``]A(`
M``83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,```````#(0P``
M`````````````````````````````````````````````````````,`3````
M```````````0````L```"E!!4BYP;0H`````U%(``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R,#(S,3`Q-```+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+F=N=2YP<F]P97)T
M>0`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M```````````````````````````+`````0````(```"T`0``M`$``!<`````
M``````````$`````````$P````<````"````S`$``,P!```D````````````
M```$`````````"8````'`````@```/`!``#P`0``*```````````````!```
M```````Y````]O__;P(````8`@``&`(``-P````%``````````0````$````
M0P````L````"````]`(``/0"```@!@``!@````$````$````$````$L````#
M`````@```!0)```4"0``8@0``````````````0````````!3````"0````(`
M``!X#0``>`T``*`````%``````````0````(````7`````D```!"````&`X`
M`!@.``"X`0``!0```!0````$````"````&4````!````!@`````0````$```
M!P```````````````0````````!@`````0````8````0$```$!```(`#````
M`````````!`````$````:P````$````&````D!,``)`3```8````````````
M```(````"````'0````!````!@```+`3``"P$P``&#``````````````$```
M``````!Z`````0````8```#(0P``R$,```<```````````````$`````````
M@`````$````"`````%````!0``!P0``````````````0`````````(@````!
M`````@```'"0``!PD```%`$`````````````!`````````"6`````0````(`
M``"$D0``A)$``+P,``````````````0`````````H`````X````#````X*T`
M`."M```$```````````````$````!````*P````/`````P```.2M``#DK0``
M!```````````````!`````0```"X````!@````,```#HK0``Z*T``/`````&
M``````````0````(````;P````$````#````V*X``-BN```H`0``````````
M```$````!````,$````!`````P````"P````L```%```````````````!```
M``````#'````"`````,````4L```%+```"P```````````````0`````````
MS`````$````P`````````!2P```Q```````````````!`````0````$````#
C``````````````!%L```U0```````````````0``````````
